@@ -7,6 +7,23 @@ use vars qw($nav_buttons_html);
 
 use base 'HTML::Latemp::NavLinks::GenHtml';
 
+__PACKAGE__->mk_accessors(qw(
+    _ext
+    )
+);
+
+sub _init
+{
+    my $self = shift;
+    my (%args) = (@_);
+
+    $self->SUPER::_init(%args);
+
+    $self->_ext($args{ext} || '.png');
+
+    return;
+}
+
 =head1 NAME
 
 HTML::Latemp::NavLinks::GenHtml::ArrowImages - A class to generate the image-based HTML of the navigation links.
@@ -14,13 +31,14 @@ HTML::Latemp::NavLinks::GenHtml::ArrowImages - A class to generate the image-bas
 =head1 SYNOPSIS
 
     my $obj = HTML::Latemp::NavLinks::GenHtml::Text->new(
+        ext => '.png', # Default.
         root => $path_to_root,
         nav_links_obj => $links,
         );
 
 =head1 DESCRIPTION
 
-This module generates text navigation links. C<root> is the relative path to 
+This module generates text navigation links. C<root> is the relative path to
 the site's root directory. C<nav_links_obj> are the hash of navigation links'
 objects as returned by L<HTML::Widgets::NavMenu> or something similar.
 
@@ -43,26 +61,27 @@ sub _get_nav_buttons_html
     my $self = shift;
 
     my (%args) = (@_);
-    
+
     my $with_accesskey = $args{'with_accesskey'};
 
     my $root = $self->root();
 
-    my $template = 
+    my $template =
         Template->new(
         {
             'POST_CHOMP' => 1,
         }
         );
-    
+
     my $vars =
     {
         'buttons' => $self->_get_buttons(),
         'root' => $root,
         'with_accesskey' => $with_accesskey,
         'image_base' => $self->get_image_base(),
+        ext => $self->_ext(),
     };
-    
+
     my $nav_links_template = <<'EOF';
 [% USE HTML %]
 [% FOREACH b = buttons %]
@@ -73,15 +92,15 @@ sub _get_nav_buttons_html
 [% IF with_accesskey %]
 accesskey="[% key %]"
 [% END %]
->[% END %]<img src="[% root %]/images/[% image_base %][% b.button %][% UNLESS b.exists %]-disabled[% END %].png"
+>[% END %]<img src="[% root %]/images/[% image_base %][% b.button %][% UNLESS b.exists %]-disabled[% END %][% ext %]"
 alt="[% b.title %]" class="bless" />[% IF b.exists %]</a>
 [% END %]
 </li>
 [% END %]
 EOF
-    
+
     my $nav_buttons_html = "";
-    
+
     $template->process(\$nav_links_template, $vars, \$nav_buttons_html);
     return $nav_buttons_html;
 }
